@@ -7,12 +7,14 @@ pub type PostgresPool = Pool<diesel::pg::PgConnection>;
 pub type DBConnectionPool = PostgresPool;
 pub type DBConnection = PooledConnection<ConnectionManager<diesel::pg::PgConnection>>;
 
-pub fn create_database_pool() -> DBConnectionPool {
+pub fn create_database_pool() -> Result<DBConnectionPool, String> {
     let database_url = std::env::var("DATABASE_URL")
-        .expect("DATABASE_URL not set");
+        .map_err(|e| e.to_string())?;
     let manager =
         ConnectionManager::<diesel::pg::PgConnection>::new(database_url);
-    Pool::builder()
-        .build(manager)
-        .expect("Failed to create pool")
+    Ok(
+        Pool::builder()
+            .build(manager)
+            .map_err(|e| e.to_string())?
+    )
 }
